#include <stdio.h>
#include <stdlib.h>

void cbem_poi_ex_int_ud(int i); /* For every triangle i, compute and add the influence contribution to all collocation */
				/* points in h and g and the contributions of the source term in srct                  */


void cbem_poi_assem(void)
{

/* ===purpose=== */

/**********************************************************************************************************************************/
/********************************  COLLOCATION BEM for 3D POISSON EQUATION: SINGULAR FORMULATION  *********************************/
/************************************  3-NODED TRIANGULAR ELEMENT: SEMI-ANALYTIC INTEGRATION  *************************************/
/***********************************************  PIECEWISE CONSTANT APPROXIMATION  ***********************************************/
/************************  Assemble h and g influence matrices and the contributions of the source term ***************************/
/**********************************************************************************************************************************/

/* Developer: Sylvain Nintcheu Fata */
/* Version:   V.1.1                 */
/* Released:  Aug 21, 2012          */

 
   extern int nbelt;     /* nbelt == Total number of boundary elements */
                         /* For Piecewise constant approximation, nbelt is also equal to the number of collocation points on the surface */
   extern double *h, *g; /* h == Coefficient matrix acting on the vector of boundary potentials <==> potential influence matrix */
                         /* g == Coefficient matrix acting on the vector of boundary fluxes <==> flux influence matrix */
   extern double *srct;  /* srct[k] == Contribution of the source term at the k-th collocation point */

   int k,snbelt;



   snbelt = nbelt*nbelt;
   if ( (h = (double *)calloc(snbelt,sizeof(double))) == NULL ) /* If h is not successfully allocated */
   {printf("cbem_poi_assem: Allocate array \"h\" failed\n"); exit(1);}
    
   if ( (g = (double *)calloc(snbelt,sizeof(double))) == NULL ) /* If g is not successfully allocated */
   {printf("cbem_poi_assem: Allocate array \"g\" failed\n"); exit(1);}
   
   if ( (srct = (double *)calloc(nbelt,sizeof(double))) == NULL ) /* If srct is not successfully allocated */
   {printf("cbem_poi_assem: Allocate array \"srct\" failed\n"); exit(1);}

/* Assemble h and g influence matrices */
   for (k=0; k<nbelt; k++) /* Loop over all boundary elements */
      cbem_poi_ex_int_ud(k); /* For every triangle k, compute and add the influence contribution to all collocation */
                             /* points in h and g and the contributions of the source term in srct                  */

}
